## Spring Cloud 从 Eureka 注册中心平滑迁移到 Nacos


### 使用方式

1. 在 pom.xml 新增两个依赖


                <dependency>
                    <groupId>com.alibaba.edas</groupId>
                    <artifactId>edas-sc-migration-starter</artifactId>
                    <version>1.0.1</version>
                </dependency>
        
                <dependency>
                    <groupId>org.springframework.cloud</groupId>
                    <artifactId>spring-cloud-starter-alibaba-nacos-discovery</artifactId>
                    <version>{相应的版本}</version>
                </dependency>
            

1. 在 application.properties 中配置注册中心地址
        
        
            spring.cloud.nacos.discovery.server-addr=127.0.0.1:8848
        
1. 在应用启动的主类中，显示地配置 Ribbon Configuration，`@RibbonClients(defaultConfiguration = MigrationRibbonConfiguration.class)`，如下所示


            @SpringBootApplication
            @EnableDiscoveryClient
            @EnableFeignClients
            @RibbonClients(defaultConfiguration = MigrationRibbonConfiguration.class)
            public class ConsumerApplication {
            
                public static void main(String[] args) {
                    SpringApplication.run(ConsumerApplication.class, args);
                }
            }


完成以上三步后，应用启动后会同时注册到 Eureka 和 Nacos，并且消费的时候也会从 Eureka 和 Nacos 订阅，并做简单的聚合。

### 如何验证

1. 增加 Actuator 后，可以通过 Endpoint 来查看 Ribbon_Server_List 的信息，对应不同的 Spring Boot 版本，地址分别为


        http://127.0.0.1:18091/migration_server_list
        http://127.0.0.1:18092/actuator/migration-server-list
        
        
### 更多控制

1. 默认从所有注册中心中订阅服务，如果想指定从某个特定的服务注册中心订阅服务，可以使用如下配置


        spring.cloud.edas.migration.subscribes=nacos,eureka # 同时从 Eureka 和 Nacos 订阅服务
        spring.cloud.edas.migration.subscribes=nacos        # 只从 Nacos 订阅服务

## 演示

本 Demo 直接包含了一个演示，演示步骤如下

1. 启动 Nacos Server
2. 执行 sh start.sh 启动
3. 分别执行 `sh curlloop1.sh` 、`sh curlloop2.sh`、`sh curlloop3.sh` 进行调用验证
4. 通过 Endpoint 查看服务列表信息
5. 通过 Nacos 控制台调整 `spring.cloud.edas.migration.subscribes` ，注意 必须先包含 `opensource-service-consumer.properties`、`opensource-service-consumer2.properties`、`opensource-service-consumer3.properties` 这几个 dataId，且里面有内容 ，才能正常地更改配置。